/* Original license from mail/components/compose/content/MsgComposeCommands.js
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is Mozilla Communicator client code, released
# March 31, 1998.
#
# The Initial Developer of the Original Code is
# Netscape Communications Corporation.
# Portions created by the Initial Developer are Copyright (C) 1998-1999, 2010
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   David Bienvenu <bienvenu@nventure.com>
#   Olivier Parniere BT Global Services / Etat francais Ministere de la Defense
#   Josh Geenen <joshgeenen+filetypeselector@gmail.com>
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****/

if (!com) {
  /** A generic wrapper variable */
  var com = {};
}

if (!com.FileTypeSelector) {
  /** A wrapper for all FTS functions and variables */
  com.FileTypeSelector = {};
}

// when the window finishes loading, override the SaveAsFile function with
// the com.FileTypeSelector.composeSaveAsFile function below
window.addEventListener("load",
  /**
   * Overrides the SaveAsFile function in
   * mail/components/compose/content/MsgComposeCommands.js
   * with com.FileTypeSelector.composeSaveAsFile to allow setting a default
   * file extension.
   */
  function FTS_loadListener(e) {
    SaveAsFile = com.FileTypeSelector.composeSaveAsFile;
  },
false);

/**
 * Meant to override the SaveAsFile method in
 * mail/components/compose/content/MsgComposeCommands.js (line 1915)
 * Allows the user to always save replies and composed e-mail as text, even if
 * they are being composed in HTML.
 *
 * This method is called from the Compose window under the following
 * circumstances:
 *   o The user goes to File -> Save As -> File (aSaveAs === file)
 *   o The user goes to File -> Save AND the variable defaultSaveOperation is
 *     "file" (aSaveAs === false)
 * @param aSaveAs {boolean} Passed to SaveDocument.  True if the user click on
 *                          'Save As' as opposed to 'Save'.
 */
com.FileTypeSelector.composeSaveAsFile = function FTS_composeSaveAsFile(aSaveAs) {
  var alwaysTxt  = false,
      prefBranch = null,
      subject    = null;
  try {
    prefBranch = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefService)
                           .getBranch("extensions.filetypeselector.")
                           .QueryInterface(Components.interfaces.nsIPrefBranch2);
    alwaysTxt = prefBranch.getBoolPref("composeAlwaysSaveAsTxt");
  }
  catch (e) {}

  subject = GetMsgSubjectElement().value;
  GetCurrentEditor().setDocumentTitle(subject);

  // Note: do not use === when comparing these two
  if (gMsgCompose.bodyConvertible() == nsIMsgCompConvertible.Plain || alwaysTxt) {
    SaveDocument(aSaveAs, false, "text/plain");
  }
  else {
    SaveDocument(aSaveAs, false, "text/html");
  }
  defaultSaveOperation = "file";
};
