/* License from mail/base/content/mailCommands.js
# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
#
# The Original Code is Mozilla Communicator client code, released
# March 31, 1998.
#
# The Initial Developer of the Original Code is
# Netscape Communications Corporation.
# Portions created by the Initial Developer are Copyright (C) 1998-1999, 2010
# the Initial Developer. All Rights Reserved.
#
# Contributor(s):
#   Magnus Melin <mkmelin+mozilla@iki.fi>
#   Josh Geenen <joshgeenen+filetypeselector@gmail.com>
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****/

if (!com) {
  /** A generic wrapper variable */
  var com = {};
}

if (!com.FileTypeSelector) {
  /** A wrapper for all FTS functions and variables */
  com.FileTypeSelector = {};
}

// when the window finishes loading, override the SaveAsFile function with
// the com.FileTypeSelector.mailCmdsSaveAsFile function below
window.addEventListener("load",
  /**
   * Overrides the SaveAsFile function in mail/base/content/mailCommands.js
   * with com.FileTypeSelector.mailCmdsSaveAsFile to allow setting a default
   * file extension.
   */
  function FTS_loadListener(e) {
    SaveAsFile = com.FileTypeSelector.mailCmdsSaveAsFile;
  },
false);

/**
 * Sets the type for saved e-mail messages as the type specified in the
 * preference for this extension (extensions.filetypeselector.defaultExtension).
 * The original is from mail/base/content/mailCommands.js
 * @param aURI {string} The URI of the e-mail message to save.
 */
com.FileTypeSelector.mailCmdsSaveAsFile = function FTS_mailCmdsSaveAsFile(aURI) {
  var type       = ".eml",
      filename   = null,
      filenames  = [],
      subject    = null,
      prefBranch = null,
      i          = 0,
      uri        = null,
      msgHdr     = null,
      name       = null,
      number     = 0;
  try {
    // get the preference for the default extension type
    prefBranch = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefService)
                           .getBranch("extensions.filetypeselector.")
                           .QueryInterface(Components.interfaces.nsIPrefBranch2);
    type = prefBranch.getCharPref("defaultExtension");
    if (type.indexOf(".") === -1) {
      type = "." + type;
    }
  }
  catch (e) {}
  // This is a little more complicated because aURI can be an array (TB 3) or
  // string (TB 2)
  switch (typeof aURI) {
  case "string": // Thunderbird 2
    try {
      subject = messenger.messageServiceFromURI(aURI)
                         .messageURIToMsgHdr(aURI)
                         .mime2DecodedSubject;
      filename = GenerateValidFilename(subject, type);
    }
    catch (ex) {}
    messenger.saveAs(aURI, true, null, filename);
    break;
  case "object": // Thunderbird 3 (instanceof Array)
    if (!(aURI instanceof Array)) {
      alert("ERROR: aURI is not a string or array in com.FileTypeSelector.mailCmdsSaveAsFile");
      return;
    }
    if (aURI.length == 1) {
      uri    = aURI[0];
      msgHdr = messenger.messageServiceFromURI(uri)
                        .messageURIToMsgHdr(uri);
      name   = msgHdr.mime2DecodedSubject;
      if (msgHdr.flags & Components.interfaces.nsMsgMessageFlags.HasRe) {
        name = (name) ? "Re: " + name : "Re: ";
      }

      filename = GenerateValidFilename(name, type);
      messenger.saveAs(uri, true, null, filename);
    }
    else {
      for (i = 0; i < aURI.length; i++) {
        msgHdr = messenger.messageServiceFromURI(aURI[i])
                          .messageURIToMsgHdr(aURI[i]);
        name   = GenerateFilenameFromMsgHdr(msgHdr);
        name   = GenerateValidFilename(name, type);
        number = 2;
        while (filenames.indexOf(name) !== -1) { // should be unlikely
          name = name.substring(0, name.length - 4) + "-" + number + type;
          number++;
        }
        filenames.push(name);
      }
      messenger.saveMessages(aURI.length, filenames, aURI);
    }
    break;
  default:
    alert("ERROR: Unrecognized typeof aURI in com.FileTypeSelector.mailCmdsSaveAsFile: '" + (typeof aURI) + "'");
  }
};
